Tento text byl publikován jako součást knihy (Lopatková et al., 2016) vydané nakladatelstvím Karolinum.

# Podoba slovníkového hesla

V této kapitole představíme slovníkové heslo z hlediska jeho struktury, jednotlivých atributů a jejich hodnot. Lingvistické aspekty vyžadující širší vysvětlení či diskusi jsou ponechány stranou, s odkazem na základní literaturu týkající se dané problematiky.

Obrázek 1: Ukázka slovníkových hesel

## 1 Lexémy, lexikální formy a lexikální jednotky

Slovník VALLEX je na nejvyšší úrovni tvořen lexémy, kterým odpovídají jednotlivá slovníková hesla. Lexémy, které jsou uvedeny slovesnými lemmaty, sdružují lexikální jednotky, odpovídající jednotlivým významům daného slovesa, viz obr. 1.1

## 2 Lemmata

Slovníkové heslo je ve VALLEXu uvedeno lemmatem, případně seznamem lemmat, tedy infinitivními tvary slovesa, reprezentujícími množinu všech jeho paradigmatických forem (tvořících formální složku lexému).

VALLEX (v návaznosti na teorii Funkčního generativního popisu, FGP, viz kapitolu THEORY) zachycuje valenční chování vidových protějšků v rámci jediného lexému. Slovníkové heslo je tak typicky uvedeno dvěma (příp. více) slovesnými lemmaty, a to nedokonavým a dokonavým infinitivním tvarem slovesa (odd. 2.1). Dalším důvodem, proč se v záhlaví slovníkového hesla může vyskytnout více lemmat, jsou pravopisné varianty slovesa (odd. 2.2).

Lemmata jsou doplněna informací o vidu (v horním indexu), případně římskou číslicí rozlišující homografy (v dolním indexu), např. nakupovatIimpf jako nedokonavý protějšek k nakoupitpf vs. nakupovatIIimpf jako nedokonavý protějšek k nakupitpf; k homografům viz odd. 2.3.

### 2.1 Vid a vidové protějšky

V češtině se pro kategorii vidu rozlišují dvě základní hodnoty, nedokonavost (imperfektiva) a dokonavost (perfektiva). Vedle toho se vyčleňují též iterativa (násobená slovesa jako specifická podtřída nedokonavých sloves) a slovesa obouvidová (slovesa, která se v určitých kontextech chovají jako dokonavá, v jiných kontextech jako nedokonavá).

Ve VALLEXu se informace o vidu zachycuje u každého lemmatu jako horní index, který může nabývat následujících hodnot:

- impf pro nedokonavá slovesa;

- pf pro dokonavá slovesa;

- iter pro iterativa;

- biasp pro obouvidová slovesa.

Identifikátorem impf, pf, iter, biasp jsou ve slovníkovém hesle uvedeny glosy a příklady, případně další údaje, které se vztahují pouze k některým z lemmat reprezentujících lexém.

V souladu s teorií FGP jsou ve VALLEXu do jediného lexému spojeny vidové dvojice tvořené sufixálně, např. ochutnávatimpf — ochutnatpf, dokončovatimpf — dokončitpf, vyrůstatimpf — vyrůstpf či otáčetimpf — otočitpf.

V rámci jednoho lexému jsou též zachyceny supletivní páry, např. brát (si)impf — vzít (si)pf či nacházetimpf — najítpf. Při stanovování vidových protějšků se VALLEX přidržuje slovníku SSJČ (Havránek et al., 1964).

Dokonavé protějšky nedokonavých sloves tvořené prefixálně v rámci jednoho lexému zachyceny nejsou: ne vždy totiž panuje shoda v určení vidových forem tvořených prefixací (viz argumentaci A. V. Isačenka, 1960); s touto teoretickou neujasněností souvisí i nejednoznačnost v případném určování, které z více možných prefigovaných lemmat považovat za vidový protějšek.

Pokud existuje běžně užívaná iterativní podoba, je rovněž zahrnuta do příslušného lexému, např. slovesa nasedatimpf — nasednoutpf — nasedávatiter odpovídají jedinému lexému popsanému v jednom slovníkovém hesle. Vzhledem k vysoké produktivitě tvoření iterativ v češtině nejsou ve VALLEXu iterativa zachycena vyčerpávajícím způsobem: iterativa s rozšířenou variantou přípony -váva(t), např. chodívávatiter, nejsou uváděna vůbec; z ostatních iterativ jsou uváděna pouze ta, která jsou doložena v korpusech SYN2005 nebo SYN2010 nebo se ve sledovaných textech a zdrojových slovnících vyskytovala pravidelněji. Pro iterativa se však neuvádějí glosy a příklady ani se nezaznamenává omezení u lexikálních jednotek, pro které se iterativum netvoří.2

V rámci jediného slovníkového hesla je v některých případech zachyceno více podob jednoho ze členů vidové dvojice (aniž by šlo o varianty, odd. 2.2), a to v případech, kdy jednomu lemmatu jedné vidové hodnoty odpovídá více různých lemmat s druhou hodnotou, např. dokonavá slovesa dohnatpf i dohonitpf mají nedokonavý protějšek dohánětimpf, naopak dokonavé sloveso odvinoutpf má dva nedokonavé protějšky odvinovatimpf a odvíjetimpf – každá tato trojice lemmat reprezentuje jediný lexém, odpovídá jí tedy jediné slovníkové heslo. V těchto případech je vidová charakteristika doplněna arabskou číslicí tak, že index s vidovou charakteristikou slouží jako jednoznačný identifikátor lemmatu ve slovníkovém hesle, např. dohánětimpf — dohnatpf1 — dohonitpf2 a odvinovatimpf1 — odvíjetimpf2 — odvinoutpf.

Slovesa s rozdílnou vidovou charakteristikou se sice liší morfologickým významem, sdílejí však lexikální jednotky (k terminologii viz odd. THEORY > 1). Lexikální jednotka se tak typicky vztahuje ke všem lemmatům daného lexému, která jsou uvedena v záhlaví slovníkového hesla. Toto obecné pravidlo má řadu výjimek – některé lexikální jednotky se mohou vztahovat jen k některým z uvedených lemmat, např. sloveso odpovědětpf je dokonavým protějškem slovesa odpovídatimpf ve významu „dávat odpověď“ a „reagovat“, ale již ne ve významech „mít odpovědnost“ nebo „být ve shodě / v souladu; korespondovat“. V takovém případě jsou za arabskou číslicí uvádějící příslušnou lexikální jednotku uvedena za značkou limit všechna lemmata, ke kterým se daná lexikální jednotka vztahuje (toto omezení nebylo systematicky anotováno pouze v případě iterativ).

### 2.2 Varianty lemmatu

Ortografické alternativy (lišící se obvykle jen alternací v morfematickém kmenu slovesa), které jsou zaměnitelné v jakémkoliv kontextu beze změny významu, a ke kterým se tedy vztahuje stejná množina lexikálních jednotek, jsou chápány jako varianty lemmatu, např. dozvědět sepf a dovědět sepf, dýchnoutpf a dechnoutpf. Tyto varianty jsou zachyceny jako množina dvou nebo více lemmat reprezentujících (spolu s lemmatem či lemmaty případných vidových protějšků) příslušný lexém.

Varianty jsou v záhlaví hesla oddělené lomítkem, např. dozvědět / dovědět seimpf, dýchnout / dechnoutpf.

Přes toto základní vymezení variant VALLEX obsahuje řídké výjimky, kdy lze v určitém významu užít pouze jedno z lemmat, srov. např. lemmata plavatimpf a plovatimpf, tradičně považovaná za varianty, v kontextu plavat v matematice vs. *plovat v matematice. V případě, že lze v daném významu užít pouze jednu z variant, je za arabskou číslicí uvádějící příslušnou lexikální jednotku za značkou limit uvedena ta varianta lemmatu, ke které se tato lexikální jednotka vztahuje (s vyznačeným videm a případně indexem pro homografy, viz níže).

### 2.3 Homografy (homonyma)

Jako homografy jsou ve VALLEXu označována především lemmata s identickou grafickou podobou, případně lemmata lišící se pouze přítomností reflexiva se/si, ale bez zřejmého sémantického vztahu. Přechod mezi homografií/homonymií 3 a polysémií (kdy jednotlivé lexikální jednotky spolu sémanticky i geneticky souvisejí) je však v jazyce plynulý, jako homografy jsou tak ve VALLEXu vyznačena i lemmata stejné grafické podoby, u nichž sice lze vysledovat sémantickou příbuznost, která se však liší videm.

Ve VALLEXu jsou homografy rozlišovány římskou číslicí uvedenou v dolním indexu, např. vylétatIimpf1 — vyletovatimpf2 — vyletět / vylétnoutpf1 — vylétatIIpf2 — vylétávatiter, dítIimpf, dítII seimpf, státIimpf — stávatIiter, státII (si)impf — stávatII (si)iter, stávatIII seimpf — státIII sepf.

### 2.4 Reflexivní lemmata

Reflexivní lemmata reprezentují reflexivní lexémy, k nimž řadíme tři typy reflexivních sloves, u nichž je reflexivum se/si součástí lemmatu (Kettnerová – Lopatková, 2014):4

- Reflexiva tantum (v Karlík et al., 2002 jsou označována jako inherentně reflexivní slovesa), tedy reflexivní slovesa, která nereflexivní protějšek nemají, např. bát seimpf, smát seimpf; podtřídu tvoří vlastní inherentní reciproka s reflexivní podobou, odd. 4.4, např. setkávat seimpf — setkat sepf; řadí se sem též reflexivní slovesa, která nereflexivní podobu sice mají, lexikální jednotky odpovídající reflexivním a nereflexivním formám si jsou však natolik významově vzdáleny, že je nelze považovat za jediný lexém, např. chovat seimpf vs. chovatimpf.

- Odvozená / sekundární reflexiva (v Karlík et al., 2002 též inherentně reflexivní varianta slovesa), tedy slovesa, kde reflexivum se/si je slovotvorným morfémem a kde reflexivní podoba je v nějakém významovém vztahu k podobě nereflexivní, např. vyjadřuje samovolnou či bezděčnou činnost, např. šířit seimpf a vracet seimpf — vrátit sepf, nebo signalizuje reciprocitu, např. líbat seimpf (v takovém případě mluvíme o odvozených recipročních slovesech, viz odd. 4.4).

- Slovesná lemmata s fakultativním reflexivem se/si, tedy slovesa, kde reflexivní lemmata sdílejí význam s nereflexivními lemmaty, a reprezentují tak stejné lexikální jednotky, např. mysletimpf a myslet siimpf v užitích Myslím, že to tak není. vs. Myslím si, že to tak není., dále začínatimpf a začínat seimpf v užitích Koncert začíná v osm hodin. vs. Koncert se začíná v osm hodin.

Reflexivní lexémy prvních dvou typů, tedy reflexiva tantum a odvozená reflexiva, jsou ve VALLEXu zachyceny v samostatných slovníkových heslech. Slovesa s fakultativním se/si jsou reprezentována v rámci jediného lexému; příslušné reflexivum je vyznačeno v závorce jako fakultativní součást příslušného lemmatu, např. myslet / myslit (si)impf a začínat (se)impf — začít (se)pf.

## 3 Lexikální jednotky

V koncepci slovníku VALLEX reprezentují lexikální jednotky významovou složku, která spolu se složkou formální (s možnými lexikálními formami) tvoří lexém. Lexikální jednotku chápeme jako „dané slovo v daném významu“, více viz kapitolu THEORY.

Pro vyčleňování jednotlivých významů daného lexému neexistují testovatelná, všeobecně přijímaná kritéria, přechod od jednoho významu ke druhému je v řadě případů pozvolný. Ve VALLEXu je při rozlišování jednotlivých lexikálních jednotek kladen důraz na syntaktická kritéria, zejména na podobu valenčního rámce, včetně morfematické realizace jednotlivých valenčních doplnění (viz odd. 3.1). Přitom se ovšem přihlíží též k sémantice.

- Změny ve valenčním rámci (v počtu, typu i obligatornosti valenčních doplnění) vedou k vyčlenění samostatných lexikálních jednotek, a to i v případě, že je význam těchto lexikálních jednotek blízký, např. následující užití slovesa posílatimpf — poslatpf bude popsáno dvěma lexikálními jednotkami: poslat peníze do banky / na účet.DIR3 vs. poslat peníze dětem.ADDR.

- K vyčlenění samostatných lexikálních jednotek vede i různá syntaktická strukturace významu spojená s lexikalizovanými alternacemi (odd. THEORY > 2), např. naložit vůz.PAT senem.EFF vs. naložit seno.PAT na vůz.DIR3; žnout trávu.PAT na louce.LOC vs. žnout louku.PAT. Tyto významově blízké lexikální jednotky jsou systematicky provázány odkazy, viz zde odd. 4.5.

- Jednotlivé valenční členy jsou specifikovány syntakticko-sémantickým vztahem k řídícímu slovesu, odlišnost tohoto vztahu opět vede k vyčlenění samostatných lexikálních jednotek, např. tři lexikální jednotky pro lexém pocházetimpf: Rukopis pochází ze 14. století.TFRWH. vs. Jan pochází z venkova.DIR1. vs. Všechno zlo pochází z bídy a neznalosti.PAT.

- Pokud má sloveso dva zřetelně odlišné významy (příp. více odlišných významů), jsou tyto významy popsány různými lexikálními jednotkami i v případech, kdy se valenční rámec neliší, např. dvě lexikální jednotky pro sloveso chovatimpf: chovat dítě.PAT v náručí.LOC vs. chovat prasata.PAT na farmě.LOC.

Lexikální jednotky jsou ve VALLEXu číslovány arabskými číslicemi; každá lexikální jednotka je uvozena touto číslicí.

Pořadí lexikálních jednotek není zcela arbitrární, není ale přísně systematické. V této podobě slovníku je dáno intuicí autorů (s přihlédnutím ke vzorku korpusového materiálu) – primární a/nebo velmi frekventované významy jsou uváděny na prvních místech, zatímco řídké a idiomatické významy jsou řazeny na konec slovníkového hesla.

Pokud není specifikováno jinak, vztahuje se lexikální jednotka ke všem lemmatům reprezentujícím daný lexém (uvedeným v záhlaví slovníkového hesla). V případech, kdy se daná lexikální jednotka vztahuje jen k některým lemmatům ze seznamu v záhlaví, jsou za značkou limit uvedena všechna lemmata (s vyznačeným videm a případnými variantami a indexem pro homografy), ke kterým se tato lexikální jednotka vztahuje. (Značka limit se však neuvádí, pokud se daná lexikální jednotka vztahuje ke všem lemmatům uvedeným v záhlaví slovníkového hesla s výjimkou iterativa, kde omezení nebylo systematicky anotováno.)

Lexikální jednotky nesou informaci o syntaktických a sémantických rysech slovesa v daném významu. Příslušné informace jsou ve VALLEXu zachyceny jako povinné a nepovinné atributy lexikální jednotky. Povinné atributy musí být vyplněny pro každou lexikální jednotku. Nepovinné atributy mohou být nevyplněny, protože buď pro danou lexikální jednotku nejsou relevantní (např. kontrola se uvádí jen u sloves s touto vlastností, viz odd. 4.1), nebo dané informace nejsou v současné podobě dostupné (např. určení syntakticko-sémantické třídy slovesa, viz odd. 4.6).

Každá lexikální jednotka je charakterizována následujícími povinnými atributy:

- valenční rámec, viz odd. 3.1;

- glosa: sloveso nebo parafráze charakterizující daný význam slovesa; glosy nelze pokládat za synonyma, neaspirují ani na lexikografické definice, slouží pouze pro orientaci ve slovníkovém hesle; glosy jsou uváděny vždy na samostatném řádku za valenčním rámcem;

- příklad: věty nebo fragmenty vět obsahující dané sloveso v daném významu, případně s označením zdroje příkladu, např. SYN, SSJČ apod.

K nepovinným atributům lexikální jednotky patří:

- kontrola, viz odd. 4.1;

- gramatikalizované alternace, a to:

  - diateze, viz odd. 4.2;

  - reflexivita, viz odd. 4.3;

  - reciprocita, viz odd. 4.4;

- lexikalizované alternace, viz odd. 4.5;

- syntakticko-sémantická třída, viz odd. 4.6;

- idiomatičnost, viz odd. 4.7.

### 3.1 Valenční rámce

Zásady valenční teorie FGP (viz zejména Panevová, 1980; Panevová, 1994), která slouží jako teoretické zázemí VALLEXu, klasifikace aktantů a volných doplnění, zásady pro jejich rozlišování i test pro stanovení obligatornosti jsou popsány v kapitole THEORY.

Nejdůležitější syntakticko-sémantická charakteristika slovesa je zachycena ve formě valenčního rámce. Valenční rámec ve VALLEXu sestává z následujících typů valenčních doplnění:

- z aktantů (obligatorních i fakultativních),

- z obligatorních volných doplnění a

- z kvazivalenčních doplnění.

Ve slovníku se kromě uvedených členů valenčního rámce uvádí i nevelké množství fakultativních volných doplnění (dále typická doplnění) charakteristických pro celé sémantické skupiny sloves.5

Ostatní volná doplnění, ačkoli se mohou se slovesy vyskytovat, nejsou ve valenčním rámci uváděna, neboť jsou podle FGP s lexikálními jednotkami volně slučitelná. Seznam valenčních doplnění uplatněných ve VALLEXu je uveden v odd. 3.2.

Ve VALLEXu je valenční rámec modelován jako posloupnost valenčních a nevalenčních pozic, kde každá pozice odpovídá jednomu valenčnímu, příp. typickému doplnění daného slovesa. Každá pozice je charakterizována:

- funktorem, označujícím typ syntakticko-sémantického vztahu mezi slovesem a jeho doplněním, viz odd. 3.2;

- seznamem možných morfematických forem, viz odd. 3.3;

- informací o obligatornosti, viz odd. 3.4.

### 3.2 Funktory pro aktanty, kvazivalenční a volná doplnění

V následujícím výčtu jsou shrnuty funktory, označující typy syntakticko-sémantického vztahu mezi slovesem a jeho doplněním, které se ve VALLEXu vyskytují. Pro úplnost zde uvádíme všechny funktory pro volná doplnění s alespoň jedním výskytem ve slovníku bez ohledu na to, zda jsou ve zde uváděných příkladových větách příslušná doplnění valenční, nebo zda jde pouze o doplnění typická, tedy nevalenční.6

##### Aktanty:

- ACT (Aktor / Konatel): Petr čte dopis.

- PAT (Patiens): Potkal jsem bratra.

- EFF (Výsledek děje / Efekt): Jmenovali ho ředitelem.

- ADDR (Adresát): Petr dal Marii knihu.

- ORIG (Původ): Upekla z jablek koláč.

##### Kvazivalenční doplnění:

- DIFF (Rozdíl): Hodnota akcií stoupla o 100 %.

- INTT (Záměr): Přišel navštívit Janu.

- OBST (Překážka): Zachytila rukou o stůl.

##### Volná doplnění (abecedně):

- ACMP (Doprovod): Matka tam šla s dětmi.

- AIM (Účel): Jan šel do pekárny pro chléb.

- BEN (Benefaktor): Připravila pro děti snídani.

- CAUS (Příčina): Petr pro nemoc končí s prací.

- COMPL (Doplněk): Pracoval jako učitel.

- CRIT (Kritérium): Třídili diamanty podle velikosti.

- DIR1 (Směr – odkud): Přišel z lesa promočený.

- DIR2 (Směr – kudy): Vydal se do sousední vesnice přes les.

- DIR3 (Směr – kam): Vydal se do sousední vesnice přes les.

- EXT (Míra): Tatínek měřil 2 metry.

- HER (Dědictví): Pojmenovali nejstaršího syna po otci.

- LOC (Místo): Narodil se v Itálii.

- MANN (Způsob): Choval se k ní laskavě.

- MEANS (Prostředek): Napsal dopis rukou.

- RCMP (Náhrada): Koupila si nové tričko za 350 Kč.

- REG (Zřetel): Situace se v tomto ohledu výrazně zlepšila.

- SUBS (Substituce): Startoval za Slávii.

- TFHL (Čas – na jak dlouho): Přerušil studium na rok.

- TFRWH (Čas – ze kdy): Jeho špatné vzpomínky pocházejí právě z tohoto období.

- THL (Čas – jak dlouho): Strávili jsme tam tři týdny.

- TOWH (Čas – na kdy): Odložili zkoušku z pondělka na úterý.

- TSIN (Čas – od kdy): Lhůtu počítáme od okamžiku dodání.

- TTILL (Čas – do kdy): Potrvá to do večera.

- TWHEN (Čas – kdy): Babička přijde zítra.

Kromě těchto funktorů se ve VALLEXu vyskytuje ještě hodnota DIR. Tato hodnota se používá jako zkratka k vyznačení, že daná lexikální jednotka je charakterizována všemi typy doplnění směru (DIR1, DIR2 a DIR3) jako typickými doplněními (tedy fakultativními doplněními typickými pro celé sémantické skupiny sloves).

##### Závislá část frazému:

- DPHR (Závislá část frazému): Novináři ho neustále chytali za slovo.

Stranou uvádíme funktor označující závislou část frazému, neboť u tohoto typu doplnění neuvažujeme o klasifikaci aktant / kvazivalenční / volné doplnění.

##### Pořadí funktorů:

Funktory jsou ve valenčním rámci uvedeny v následujícím pořadí:

1. aktanty (jsou uváděny v tzv. systémovém uspořádání, tedy v pořadí ACT – ADDR – PAT – ORIG – EFF, více viz Sgall et al., 1986a);

2. obligatorní volná doplnění (v pořadí vybraném autorem hesla),

3. kvazivalenční doplnění (v pořadí vybraném autorem hesla),

4. typická doplnění (v pořadí vybraném autorem hesla).

### 3.3 Morfematické vyjádření

Každá valenční i nevalenční pozice může být ve větě vyjádřena omezenou množinou výrazových prostředků, morfematických forem. Ve VALLEXu je množina možných forem specifikována buď explicitně, nebo implicitně.

U explicitně zachycených forem jsou možné morfematické formy dány výčtem u dané pozice valenčního rámce (dolní index u příslušného funktoru).

- U aktantů a kvazivalenčních doplnění je tento seznam forem úplný (udávají se formy pro nepříznakové, tedy aktivní, nereflexivní, nereciproční užití slovesa)7 – jiné prostředky nelze pro vyjádření těchto valenčních doplnění užít.8

- V případě volných doplnění jsou explicitně uvedené formy pro dané sloveso pouze typické, lze užít i další formy dané sémantikou doplnění.

U implicitně zachycených forem se předpokládá, že množina možných forem je dána sémantikou doplnění, tedy vyplývá z příslušného funktoru. Jinými slovy, doplnění se může realizovat jakoukoliv formou vyjadřující daný typ doplnění; její výběr je ovšem závislý na lexikálním obsazení a kontextových podmínkách, např. bydlí na kopci.LOC vs. bydlí ve vesnici.LOC, napsal dopis rukou.MEANS vs. napsal dopis na počítači.MEANS.

##### Explicitně zachycené formy.

Seznamy morfematických forem, které se mohou vyskytnout u jednotlivých valenčních pozic, sestávají z následujících typů hodnot:

- Bezpředložkové pády. Jednotlivé pády jsou označeny příslušnými číslicemi: 1 – nominativ, 2 – genitiv, 3 – dativ, 4 – akuzativ, 5 – vokativ, 7 – instrumentál.

- Předložkové skupiny. Jsou určeny lemmatem předložky (v její nevokalizované podobě) a číslem pádu (např. z+2, na+4, o+6, …). Ve VALLEXu se vyskytují následující předložky: bez, do, jako,9 jako na, k, kolem, kvůli, mezi, místo, na, nad, o, od, po, pod, podle, pro, proti, před, přes, při, s, u, v, z, za.

- Infinitivní konstrukce. Značka inf reprezentuje valenční doplnění ve formě infinitivu slovesa (ve vzácných případech též se spojkou než+inf).

- Závislé věty. Závislé věty obsahové uvozené podřadicí spojkou jsou reprezentovány lemmatem této spojky; ve VALLEXu se vyskytují následující spojky: aby, ať, jak, zda,10 že.
  Závislé věty obsahové, které nejsou uvozeny spojkami (např. nepřímé otázky uvozené tázacím zájmenem nebo adverbiem), jsou reprezentovány zkratkou cont.

- Konstrukce s adjektivy. Zkratka adj-číslice specifikuje doplnění ve formě přídavného jména v příslušném pádu (např. adj-1 pro cítím se slabý), případně v kombinaci s předložkou (např. za+adj-4 pro jeho chování měl za neslušné).

- Konstrukce s být. Infinitiv slovesa být se může vyskytnout v konstrukci s adjektivem či s bezpředložkovým pádem (např. být+adj-1 pro zdá se to být dostatečné, být+7 pro demolice se zdá být řešením).

- Část frazému. U frazeologických jednotek platí, že pokud je množina lexikálních forem, které naplňují určitou valenční pozici, omezená (často jednočlenná), jsou ve VALLEXu uvedeny přímo tyto lexikální formy (např. napospas pro frazém ponechat napospas).

##### Implicitně zachycené formy.

Pokud není u volného doplnění explicitně určena jeho možná forma, potom množina možných forem vyplývá z funktoru pro toto doplnění. Následující výčet udává formy obvyklé pro dané funktory (seznam vychází z nejčastějších forem pro jednotlivé funktory v Pražském závislostním korpusu).

- ACMP: bez+2, s+7, společně s+7, spolu s+7, v čele s+7, v souvislosti s+7, ve spojení s+7, včetně+2, … ;

- AIM: do+2, k+3, na+4, o+4, pro+4, pro případ+2, proti+3, v zájmu+2, za+4, za+7, aby, ať, že, … ;

- BEN: 3, na+4, na účet+2, na úkor+2, na vrub+2, pro+4, proti+3, v+4, ve prospěch+2, v rozporu s+7, v zájmu+2, … ;

- CAUS: 7, díky+3, kvůli+3, na+4, na+6, na základě+2, nad+7, následkem+2, od+2, pod+7, pod náporem+2, pod tíhou+2, pod váhou+2, pro+4, v+6, v důsledku+2, v souvislosti s+7, vinou+2, vlivem+2, vzhledem k+3, z+2, z důvodu+2, za+4, za+7, zásluhou+2, adverb, aby, jelikož, ježto, poněvadž, protože, že, … ;

- CRIT: 2, 7, dle+2, na+6, na základě+2, po vzoru+2, podle+2, přiměřeně+3, v+6, v duchu+2, v rozporu s+7, ve shodě s+7, ve smyslu+2, v souladu s+7, v souhlase s+7, ve světle+2, v závislosti na+6, z titulu+2, … ;

- DIR1: od+2, s+2, z+2, ze strany+2, zpod+2, zpoza+2, adverb, … ;

- DIR2: 7, cestou+2, kolem+2, mezi+7, napříč+7, po+6, podél+2, přes+4, skrz+4, v+6, adverb, …;

- DIR3: 7, do+2, do čela+2, k+3, kolem+2, mezi+4, mimo+4, na+4, na+6, nad+4, naproti+3, okolo+2, po+4, po+6, pod+4, proti+3, před+4, přes+4, směrem do+2, směrem k+3, směrem na+4, v+4, vedle+2, za+4, za+7, adverb, … ;

- EXT: 2, 4, 7, do+2, k+3, kolem+2, na+4, na+6, nad+4, okolo+2, po+6, pod+7, přes+4, v+4, z+2, za+4, adverb, … ;

- HER: po+6, podle+2, … ;

- LOC: blízko+2, blízko+3, daleko+2, do+2, kolem+2, mezi+7, mimo+4, na+4, na+6, na úroveň+2, nad+7, naproti+3, nedaleko+2, okolo+2, po+6, poblíž+2, pod+7, podél+2, proti+3, před+7, přes+4, při+6, stranou+2, u+2, uprostřed+2, uvnitř+2, v+6, v čele+2, v oblasti+2, v rámci+2, v řadě+2, vedle+2, za+4, za+7, adverb, … ;

- MANN: 7, do+2, formou+2, na+4, na+6, nad+4, o+4, po+6, pod+7, proti+3, před+7, přes+4, při+6, s+7, v+4, v+6, ve formě+2, v podobě+2, vedle+2, z+2, za+4, za+7, jak, že, adverb, … ;

- MEANS: 7, cestou+2, díky+3, do+2, na+4, na+6, o+6, po+6, pod+7, pomocí+2, prostřednictvím+2, přes+4, s+7, s pomocí+2, skrz+4, v+6, z+2, za+4, za pomoci+2, že, adverb, … ;

- REG: 7, bez ohledu na+4, bez zřetele k+3, k+3, kolem+2, na+4, na+6, na téma+2, nad+7, nezávisle na+6, o+6, ohledně+2, po+6, pro+4, před+7, při+6, s+7, s ohledem na+4, se zřetelem k+3, se zřetelem na+4, u+2, v+6, v otázce+2, v případě+2, v rámci+2, v souvislosti s+7, ve věci+2, ve vztahu k+3, vůči+3, vzhledem k+3, z+2, z hlediska+2, za+4, adverb, … ;

- SUBS: jménem+2, místo+2, namísto+2, výměnou za+4, za+4, … ;

- TFHL: do+2, na+4, po+2, pro+4, adverb, … ;

- TFRWH: od+2, z+2, … ;

- THL: 2, 4, 7, do+2, na+4, po+4, po dobu+2, přes+4, v+2, za+4, adverb, až, dokud, … ;

- TOWH: do+2, k+3, na+4, pro+4, adverb, … ;

- TSIN: od+2, počínaje+7, z+2, adverb, … ;

- TTILL: do+2, k+3, po+4, adverb, až, dokud, než, … ;

- TWHEN: 2, 4, 7, do+2, k+3, kolem+2, koncem+2, mezi+7, na+4, na+6, na závěr+2, než, o+6, okolo+2, po+6, počátkem+2, postupem+2, poté co, před+7, předtím než, při+6, s+7, u příležitosti+2, v+4, v+6, v době+2, v období+2, v průběhu+2, v závěru+2, z+2, za+2, za+4, začátkem+2, adverb, až, jakmile, když, …

### 3.4 Obligatornost slovesného doplnění

Ve VALLEXu se (v souladu s valenční teorií FGP) slovesná doplnění dělí na obligatorní a fakultativní (Panevová, 1980). Obligatorností se rozumí povinná přítomnost daného doplnění v hloubkové (tektogramatické) struktuře, více viz odd. THEORY > 1.3.

Opozice obligatornosti a fakultativnosti se týká aktantů, kvazivalenčních doplnění i volných doplnění. Je proto zachycena u každé pozice valenčního rámce:

- Obligatorní doplnění (aktanty, kvazivalenční i volná doplnění) jsou tištěna zvýrazněným písmem, např. LOC značí obligatorní volné doplnění Místo.

- Stejným písmem jsou tištěny i fakultativní aktanty a kvazivalenční doplnění (patří též do úzce chápaného valenčního rámce), ty jsou navíc odlišeny značkou opt v horním indexu, např. EFFopt značí fakultativní aktant Efekt.

- Typická volná doplnění, která rozšiřují tradiční valenční rámec, jsou tištěna obyčejným písmem a označena horním indexem typ, např. BENtyp značí typické volné doplnění Benefaktor.

## 4 Doplňující syntaktické informace

Jednotlivé lexikální jednotky mohou být obohaceny o nepovinné, doplňující syntaktické, případně syntakticko-sémantické informace úzce související s valencí slovesa. Ve VALLEXu je zachycena informace o kontrole (odd. 4.1) a o gramatikalizovaných alternacích, a to o diatezích (odd. 4.2), o reflexivitě (odd. 4.3) a o reciprocitě (odd. 4.4). Tyto gramatické jevy přímo ovlivňují povrchové projevy valence.

Dále se u vybraných lexikálních jednotek uvádí odkaz na lexikální jednotky ve vztahu lexikalizované alternace (odd. 4.5) a jejich zařazení do syntakticko–sémantické třídy (odd. 4.6), která umožňují zkoumat, jak se sémantická blízkost sloves odráží v jejich valenčních vlastnostech.

Z pohledu valence je relevantní též příznak pro idiom (odd. 4.7), neboť frazémy a idiomy často vykazují specifické valenční chování.

### 4.1 Kontrola

Termínem kontrola (značka control) se ve VALLEXu rozumí vlastnost některých sloves (tzv. sloves kontroly) vyžadovat koreferenci mezi některým svým valenčním doplněním („controller“) a valenčním doplněním podřízeného slovesa („controllee“) (viz zejm. Panevová, 1996). Ve VALLEXu je tento vztah zaznamenán pouze pro slovesa, která mohou mít valenční doplnění ve formě infinitivu (bez ohledu na jeho funktor). Za kontrolovaný člen („controllee“) je pak považován subjekt tohoto infinitivu (který je v povrchové podobě věty v češtině nevyjádřitelný), kontrolující člen („controller“) je výraz s ním koreferenční, typicky člen valenčního rámce řídícího slovesa kontroly.

Ve VALLEXu je kontrola zachycena v atributu control následujícím způsobem:

- atribut control má hodnotu funktoru toho doplnění z valenčního rámce slovesa kontroly, které je v koreferenčním vztahu s (nevyjádřeným) subjektem infinitivu;

- atribut control má hodnotu controlex v případě, že ve valenčním rámci řídícího slovesa kontroly nelze takové doplnění identifikovat.

Atribut control je vyznačen u 520 lexikálních jednotek.

Příklady:

- control: ACT, např. pokoušet seimpf — pokusit sepf, srov. Jiří.ACT se pokusí přijít. (~ Jiří přijde.)

- control: PAT, např. slyšetimpf, srov. Děti slyší někoho.PAT přicházet. (~ Někdo přichází.)

- control: ADDR, např. doporučovatimpf — doporučitpf, srov. Doporučili mu.ADDR jít k lékaři. (~ (On) jde k lékaři.)

- control: controlex , např. jítimpf, srov. Jde to udělat. (ve smyslu „lze to udělat“) (~ Kdokoli to může udělat.)

### 4.2 Diateze

Slovník VALLEX u lexikálních jednotek zachycuje možnost tvořit příznakové konstrukce jednotlivých diatezí, neboť tyto konstrukce systematickým způsobem mění valenční charakteristiku sloves: diateze jsou typicky spojeny s odsunutím situačního participantu odpovídajícího Konateli (ACT) z prominentní syntaktické pozice subjektu, přičemž korespondence situačních participantů a valenčních doplnění zůstává zachována (Panevová et al., 2014), více zde odd. THEORY > 2; z formálního hlediska tyto změny popisuje gramatická komponenta.11

V datové komponentě VALLEXu je v atributu diat uveden výčet možných diatezí, do nichž daná lexikální jednotka slovesa vstupuje. Tento atribut může nabývat následujících hodnot:

- pass pro diateze, v jejichž příznakovém členu má sloveso formu trpného participia s pomocným slovesem být (vyznačeno u 3 346 lexikálních jednotek);
  explicitně označuje diatezi pasivní, implicitně zahrnuje i diatezi rezultativní prostou;

- deagent pro diateze, v nichž je příznakový člen realizován reflexivní formou slovesnou (4 115 lexikálních jednotek);
  explicitně vyznačuje deagentní diatezi, implicitně diatezi dispoziční;

- poss pro diateze, v nichž sloveso v příznakovém členu má formu trpného participia s pomocným slovesem mít (1 866 lexikálních jednotek);
  explicitně vyznačuje rezultativ posesivní, u příkladů jsou rozlišeny následující podtypy:

  - possnconv: nekonverzní typ, kdy subjektem v příznakové konstrukci je Konatel,

  - possconv: konverzní typ, kdy je Konatel v příznakové konstrukci odsunut z pozice subjektu,

  - poss: homonymní případy, které lze rozlišit až na základě širšího kontextu;

  implicitně označuje též recipientní pasivní diatezi s pomocným slovesem mít;

- recipient pro recipientní pasivní diatezi, u níž má sloveso v příznakovém členu formu trpného participia s pomocným slovesem dostat (127 lexikálních jednotek).

Příznakové členy jednotlivých diatezí jsou ve VALLEXu exemplifikovány příklady z Českého národního korpusu (řada SYN).

### 4.3 Reflexivita

Reflexivitou se zde rozumí skutečnost, že reflexivní osobní zájmeno (jeho krátké, klitické formy se/si a dlouhé formy sebe/sobě) vyjadřují referenční totožnost aktantu v subjektové pozici (typicky Konatele (ACT)) a aktantu vyjádřeného daným reflexivem; užití reflexivního osobního zájmena vyjadřuje, že Konatel vykonává děj sám na sobě.

Ve VALLEXu je možnost reflexivního užití zachycena v atributu refl,12 který může nabývat následujících dvou hodnot:

- coref4 pro syntaktickou reflexivitu, při níž reflexivní osobní zájmeno vyjadřuje referenční totožnost aktantu v subjektové pozici a akuzativního aktantu vyjádřeného tímto reflexivem, např. mýt se / sebe, vidět se / sebe, kde reflexivní osobní zájmeno je Patientem (PAT) koreferujícím s Konatelem (ACT) slovesa mýtimpf, vidětpf (vyznačeno pro 428 lexikálních jednotek);

- coref3 pro syntaktickou reflexivitu, při níž reflexivní osobní zájmeno vyjadřuje referenční totožnost aktantu v subjektové pozici a dativního aktantu vyjádřeného tímto reflexivem, např. darovat si / sobě něco, kde reflexivní osobní zájmeno je Adresát (ADDR) slovesa darovatpf koreferující s Aktorem (ACT) tohoto slovesa (466 lexikálních jednotek).

VALLEX se omezuje na zachycení těch případů syntaktické reflexivity, která může být vyjádřena krátkými (klitickými) tvary reflexivního osobního zájmena. Nepokrývá tedy případy, kdy je gramatikalizována dlouhá forma reflexiva, např. v předložkové skupině, srov. Ode dneška (my.ACT) děláme na sebe.PAT., Rodiče.ACT ponechali doklady u sebe.LOC., v pádech, kde reflexivum nemá klitickou formu (tedy v genitivu nebo v instrumentálu), či je součástí idiomu, srov. Praštil sebou o postel. 13

### 4.4 Reciprocita

Reciprocita je operace, při níž – jsou-li splněny podmínky pro její uplatnění – vstupují některé situační participanty (a jim odpovídající valenční doplnění) do vztahu symetrie (Panevová, 1999; Panevová, 2007; Panevová – Mikulová, 2007); reciprocitou se tedy rozumí možnost vyjádření vztahu vzájemnosti mezi dvěma (či více) valenčními doplněními (Karlík et al., 2002), viz též odd. THEORY > 2.

V návaznosti na Panevovou a Mikulovou (2007) rozlišujeme vzhledem k reciprocitě tři typy sloves:

- A. Inherentně reciproční slovesa, tedy slovesa, která reciprocitu nesou již ve svém lexikálním významu; jedná se jednak o slovesa s reflexivní formou (nereflexivní forma slovesa buď vůbec neexistuje, nebo nese výrazně odlišný význam), např. setkávat seimpf — setkat sepf, dále hádat seimpf či utkávatII seimpf — utkatII sepf, jednak o slovesa s formou nereflexivní, např. soutěžitimpf a diskutovatimpf.

- B. Odvozená reciproční slovesa, tedy slovesa, která vznikla odvozením od tranzitivních sloves a získala rys inherentní reciprocity, např. líbat seimpf, dále potkávat seimpf — potkat sepf či lišit seimpf; typicky se vyznačují obligatorním doplněním s formou s+7.

- C. Ostatní slovesa s možností recipročního užití, tedy slovesa, která nenesou reciprocitu ve svém lexikálním významu, přesto reciproční užití umožňují, např. líbatimpf, dále potkávatimpf — potkatpf či lišitimpf, ale i fotografovatimpf či napodobovatimpf — napodobitpf a oceňovatimpf — ocenitpf.

Ve VALLEXu je možnost recipročního užití vyznačena u všech tří typů sloves;14 příslušné lexikální jednotky mají v atributu recipr pomocí funktorů specifikovánu dvojici, příp. trojici valenčních doplnění, která mohou být užita recipročně.

Příklady:

- ACT-ADDR, např. hádat seimpf, srov. Petr a Pavel se spolu neustále hádali.;

- ACT-PAT, např. navštěvovat seimpf — navštívit sepf, srov. Navštěvovali se pravidelně celá léta.;

- ACT-PAT, např. seznamovat seimpf — seznámit sepf, srov. Seznámili se spolu před třiceti lety.;

- ADDR-PAT, např. seznamovatimpf — seznámitpf, srov. Jan děti navzájem seznámil.;

- ACT-PAT, např. lišit seimpf, srov. Petr a Pavel se ve svém hodnocení studentů liší.;

- ACT-ADDR-PAT, např. představovatimpf — představitpf, srov. Kolegové se vzájemně představili. 15

VALLEX se omezuje na zachycení případů reciprocity, do které vstupují aktanty a obligatorní volná doplnění slovesa; ve slovníku je možnost recipročního užití vyznačena u 2 039 lexikálních jednotek.

### 4.5 Lexikalizované alternace

Lexikalizované alternace se týkají vztahů mezi odlišnými lexikálními jednotkami téhož slovesného lexému, které se vyznačují totožným situačním významem, avšak odlišují se ve strukturním významu (Panevová et al., 2014). V těchto případech je stejná množina situačních participantů pokaždé jiným způsobem rozmístěna do valenčního rámce.

Ve slovníku VALLEX jsou alternace zachyceny pomocí následujících atributů:

- conv pro lexikálněsémantické konverze;

- multiple pro rozdílnou strukturní realizaci téhož situačního participantu;

- split pro strukturní rozpad situačního participantu na dvě valenční doplnění.

Tyto typy lexikalizovaných alternací se dále klasifikují podle zasažených situačních participantů.

##### Lexikálněsémantické konverze: conv

Tato alternace je vyznačena u 313 lexikálních jednotek.

A. Objektové konverze

- Locatum-Location (lokativní konverze) (ve VALLEXu 148 lexikálních jednotek)

  - Vytvoření souvýskytu (formation), např. Řidič načerpal benzín do nádrže. – Řidič načerpal plnou nádrž benzínu.

  - Vytvoření souvýskytu (formation person), např. Matka oblékla dětem sváteční šaty. – Matka oblékla děti do svátečních šatů.

  - Zrušení souvýskytu (destruction), např. Petra vyčistila skvrnu ze sukně. – Petra vyčistila sukni od skvrn.

  - Zrušení souvýskytu (destruction person), např. Matka svlékala dítěti kabát. – Matka svlékala dítě z kabátu.

- Material-Product (82 lexikálních jednotek), např. Jan lámal kousky z tabulky čokolády. – Jan lámal tabulku čokolády na kousky.

- Theme-Path (4 lexikální jednotky), např. Sebevrah si prohnal kulku hlavou. – Sebevrah si prohnal hlavu kulkou.

- Hole-Affected_object (4 lexikální jednotky), např. Rybáři prolomili díru do ledu. – Rybáři prolomili led.

- Affliction-Patient (8 lexikálních jednotek), např. Lékař vyléčil pacientovi nemoc. – Lékař vyléčil pacienta z nemoci.

- Theme_1-Theme_2 (18 lexikálních jednotek), např. Vyměnila s kamarádem autíčko za mašinku. – Vyměnila s kamarádem mašinku za autíčko. (ve významu „pozbyla autíčko, nabyla mašinku“)

B. Subjektové konverze

- Bearer_of_action-Location (28 lexikálních jednotek), např. V klášteře zněla majestátní hudba. – Klášter zněl majestátní hudbou.

- Substance-Source (12 lexikálních jednotek), např. Na letišti explodovala bomba. – Letiště explodovalo.

- Locatum-Location (objectless) (lokativní konverze bez objektu) (10 lexikálních jednotek), např. Z plného popelníku se vysypal popel. – Popelník se vysypal.

##### Rozdílná strukturní realizace téhož situačního participantu: multiple

Tato alternace je vyznačena u 138 lexikálních jednotek.

A. Rozdílná strukturní realizace téhož participantu u sloves pohybu

- Source (4 lexikální jednotky), např. Výletníci scházeli z kopce. – Výletníci scházeli kopec.

- Path (16 lexikálních jednotek), např. Děti probíhaly lesem. – Děti probíhaly les.

- Goal (8 lexikálních jednotek), např. Výprava vyšla na kopec. – Výprava vyšla kopec.

- Boundary (10 lexikálních jednotek), např. Ostružiní přerůstá přes plot. – Ostružiní přerůstá plot.

- Area (2 lexikální jednotky), např. Kostelem prolínala vůně kadidla. – Kostel prolínala vůně kadidla.

- Impactee (10 lexikálních jednotek), např. Jan bušil do soupeře pěstmi. – Jan bušil soupeře pěstmi.

B. Rozdílná strukturní realizace téhož participantu u sloves umístění

- Location (58 lexikálních jednotek), např. Nájemníci ukládají odpad do kontejneru. – Nájemníci ukládají odpad v kontejneru.

C. Rozdílná strukturní realizace téhož participantu u sloves cogitandi a u sloves pocitů a stavů

- Judgment (12 lexikálních jednotek), např. Tuto událost vykládáme jako nepolitickou. – Tuto událost vykládáme nepoliticky.

- Subject_matter (4 lexikální jednotky), např. Studenti zaměřovali své studium spíš na lingvistiku. – Studenti zaměřovali své studium spíš lingvisticky.

- Subject_matter (objectless) (4 lexikální jednotky), např. Jan se zaměřoval na lingvistiku. – Jan se zaměřoval lingvisticky.

- State (4 lexikální jednotky), např. Zprávy o něm ho uchovaly živého. – Zprávy o něm ho uchovaly naživu.

- State (objectless) (6 lexikálních jednotek), např. Jan se v poslední době cítil jako stařík. – Jan se v poslední době cítil staře.

##### Rozpad situačního participantu na dvě valenční doplnění: split

Tato alternace je vyznačena u 318 lexikálních jednotek.

- Information (152 lexikálních jednotek), např. Sousedka si stěžovala rodičům, že syn pije. – Sousedka si stěžovala rodičům na syna, že pije.

- Phenomenon (58 lexikálních jednotek), např. Jan si pomyslel, že je Petra nafoukaná. – Jan si pomyslel o Petře, že je nafoukaná.

- Inference (8 lexikálních jednotek) Zdálo se mi, že je to změna k dobrému. – Zdálo se mi to být změnou k dobrému.

- Stimul (76 lexikálních jednotek), např. V okně prvního poschodí zahlédla, jak se na ni její manžel dívá. – V okně prvního poschodí zahlédla svého manžela, jak se na ni dívá.

- Path (26 lexikálních jednotek), např. Přívoz převáží turisty přes řeku. – Přívoz převáží turisty z jedné strany řeky na druhou.

### 4.6 Syntakticko-sémantické třídy

Část lexikálních jednotek (3 114 z celkového počtu 6 711, tedy přibližně 46 % všech lexikálních jednotek) má určenu syntakticko-sémantickou třídu (značka class). Tyto třídy byly budovány striktně „zdola nahoru“ – seskupováním lexikálních jednotek s podobnými syntaktickými vlastnostmi, přičemž se přihlíželo k jejich sémantice. Zdůrazněme zde, že syntakticko-sémantické třídy jsou tvořeny jednotlivými lexikálními jednotkami, nikoliv celými lexémy – víceznačný lexém se tedy může vyskytovat v několika třídách.

Bylo vytvořeno následujících 22 syntakticko-sémantických tříd:

- appoint verb (24 lexikálních jednotek), např. nominovatbiasp, určovatimpf — určitpf (~ určovala své zástupce), ustanovovatimpf — ustanovitpf;

- cause motion (38 lexikálních jednotek), např. mávatimpf — mávnoutpf, hýbatimpf — hnoutpf1 — hýbnoutpf2 (~ hýbat pravou rukou);

- combining (94 lexikálních jednotek), např. míchatimpf (~ míchat žloutky s moukou v těsto), přidávatimpf — přidatpf, spojovatimpf — spojitpf;

- communication (428 lexikálních jednotek), např. čístimpf, hovořitimpf, nařizovatIIimpf — naříditIIpf;

- contact (125 lexikálních jednotek), např. dotýkat seimpf — dotknout sepf, narážetimpf — narazitpf, tisknoutimpf;

- emission (22 lexikálních jednotek), např. pouštětimpf — pustitpf (~ tričko pouštělo barvu), vysílatimpf — vyslatpf (~ vysílat signály);

- exchange (182 lexikálních jednotek), např. dávatimpf — dátpf, dostávatIimpf — dostatpf, měnitimpf, platitimpf, pronajímatimpf — pronajmoutpf;

- expansion (20 lexikálních jednotek), např. pronikatimpf — proniknoutpf, šířitimpf;

- extent (18 lexikálních jednotek), např. činitimpf (~ činí to 30 Kč), dosahovatimpf — dosáhnoutpf, vycházetimpf — vyjítpf (~ boty vycházejí na tisíc korun);

- change (342 lexikálních jednotek), např. klesatimpf — klesnoutpf (~ teplota prudce klesala), budovatimpf, proměňovatimpf — proměnitpf, růstimpf;

- intervention (10 lexikálních jednotek), např. mluvitimpf (~ do toho nemůžu mluvit), zasahovatimpf — zasáhnoutpf;

- location (414 lexikálních jednotek), např. doplňovatimpf — doplnitpf (~ doplňovat zboží do regálu), nacházetimpf — najítpf, shromažďovatimpf — shromážditpf;

- mental action (338 lexikálních jednotek), např. cítit seimpf (~ cítit se dobře), jásatimpf, mrzetpf;

- modal verb 16 (15 lexikálních jednotek), např. dovéstIIimpf (~ dovede plavat), moci / moctimpf, chtítimpf, smětimpf;

- motion (311 lexikálních jednotek), např. běžetimpf, dorážetimpf — dorazitpf, hýbat seimpf — hnout sepf (~ Nehýbej se!);

- perception (98 lexikálních jednotek), např. hledětimpf, pamatovat (si)impf, všímat siimpf — všimnout sipf;

- phase of action (78 lexikálních jednotek), např. končit (se)impf (~ přednáška končí v 5 hodin), vrcholitimpf, vznikatimpf — vzniknoutpf;

- phase verb (77 lexikálních jednotek), např. iniciovatbiasp, končit (se)impf (~ končit školu);

- providing (57 lexikálních jednotek), např. naplňovatimpf — naplnitpf (~ naplnit vanu vodou), vybavovatimpf — vybavitpf;

- psych verb (143 lexikálních jednotek), např. klamatimpf, potěšitpf (~ potěšila ho dárkem, dárek ho potěšil);

- social interaction (86 lexikálních jednotek), např. potkávat seimpf — potkat sepf (~ potkává se s přáteli v baru), spojovatimpf — spojitpf (~ spojím se s ním co nejdříve), souhlasitimpf;

- transport (194 lexikálních jednotek), např. donášetimpf — donéstpf, přemisťovat / přemísťovatimpf — přemístitpf, shrnovatimpf — shrnoutpf.

Toto rozdělení lexikálních jednotek do syntakticko-sémantických tříd je pouze pracovní a nelze je považovat za klasifikaci splňující požadavky dobře definované ontologie. Je zřejmé, že takto hrubé rozdělení není syntakticky ani sémanticky homogenní, jde o základní vymezení skupin sloves, které je potřeba dále podrobně studovat. Motivací pro tuto předběžnou klasifikaci lexikálních jednotek byla skutečnost, že i takovéto pracovní třídění zachycuje vztahy mezi slovesy a díky tomu usnadňuje kontroly konzistence slovníku a dovoluje formulovat obecnější pozorování týkající se slovníkových dat.

### 4.7 Frazémy a idiomy

Při vytváření slovníku VALLEX byl kladen důraz především na úplné pokrytí primárních a obvyklých významů sloves. Zároveň bylo zpracováno mnoho lexikálních jednotek popisujících okrajová a idiomatická užití sloves; jejich pokrytí však není (a nemůže být) úplné. Takové lexikální jednotky jsou odlišeny značkou idiom za číslem lexikální jednotky.

Idiomatická užití sloves jsou taková ustálená užití, která jsou charakterizována buď podstatným posunem ve významu (vzhledem k primárnímu významu, např. přišel o hodinky), omezenou, obvykle velmi malou množinou možných lexikálních hodnot, kterých mohou jejich doplnění nabývat (např. brát roha, mráz mi z toho běhal po zádech), nebo jinými nepravidelnostmi a anomáliemi.

Poznámka:
Metaforické užití slovesa – pokud nedošlo k jeho výrazné lexikalizaci – je obvykle pokryto lexikální jednotkou pro primární význam slovesa, např. užití slovesa jítimpf v kontextu Po městě šla řeč, že se budeš stěhovat. je řazeno k lexikální jednotce popisující význam „pohybovat se po vlastních nohou; přemísťovat se chůzí“.

### Poznámky

- ^[1] K termínu lexém viz kapitolu THEORY.
- ^[2] V omezeném počtu jsou však pro iterativa ve slovníku uváděny příklady diatezí.
- ^[3] Držíme se zde terminologie běžné v anglicky psané literatuře, která rozlišuje homografy jako jednotky se stejnou psanou podobou (bez ohledu na podobu zvukovou) a homofony jako jednotky se zvukově stejnou podobou. Termín homograf užívaný ve VALLEXu tedy označuje jak homonyma (jednotky se stejnou psanou i zvukovou podobou), tak homografy (jednotky se stejnou psanou, ale odlišnou zvukovou podobou), jak tyto termíny užívá česky psaná literatura (Karlík et al., 2002).
- ^[4] O reflexivních užitích nereflexivních lexémů pojednáváme v příslušných oddílech věnovaných deagentní diatezi (odd. 4.2), reflexivitě (odd. 4.3) a reciprocitě (odd. 4.4).
- ^[5] Tato doplnění se v teorii FGP chápou jako doplnění nevalenční, ve VALLEXu se však uvádějí, protože tato informace může být s úspěchem využita např. při automatické analýze češtiny.
- ^[6] Množina funktorů, se kterými se pracuje ve FGP (a která je využita v Pražském závislostním korpusu), je bohatší (viz např. Panevová et al., 2014). Některé z těchto funktorů se však nevyskytují u slovesných doplnění, např. MAT, označující partitiv, srov. sklenice piva.MAT. Jiné funktory specifikují vztahy, které nejsou závislostní, např. koordinaci, srov. Petr, nebo.DISJ Marie. Další funktory sice reprezentují závislostní vztahy u sloves, nemají však nikdy valenční povahu, např. ATT, označující postoj, srov. udělal to dobrovolně.ATT.
- ^[7] Viz poznámku pod čarou 19 v kapitole THEORY.
- ^[8] Morfematické formy, které jsou dány gramatickými pravidly, např. pasivizací nebo reciprocitou, jsou popsány v gramatické komponentě slovníku, viz část GRAMMAR, Gramatická komponenta. Formy pro partitiv, např. dodat sůl – dodat soli, distributivnost, např. rozdal jim jablíčka – rozdal jim po jablíčku, či méně přesnou kvantifikaci, např. přišlo padesát lidí – přišlo na padesát lidí, přišlo okolo padesáti lidí, jsou ponechány zcela stranou.
- ^[9] Spojku jako zde uvádíme mezi předložkami, neboť konkrétní valenční doplnění uvozené touto spojkou vyžaduje vždy určitý pád substantiva, který však může podléhat změnám v závislosti na syntaktickém okolí, viz syntaktickou reflexivitu, odd. THEORY > 2.
- ^[10] Podoba zda je užita i pro reprezentaci spojky jestli.
- ^[11] Gramatická komponenta slovníku (zde část GRAMMAR) obsahuje pravidla, pomocí nichž je možné z valenčního rámce pro nepříznakové užití slovesa (uvedeného u každé lexikální jednotky) odvodit morfematické formy valenčních doplnění typické pro příznakové konstrukce diatezí, označované dále též jako valenční rámce pro příznakové členy diateze (případně též odvozené valenční rámce), viz též odd. THEORY > 2.
- ^[12] Atribut refl se netýká případů, kdy je reflexivum se/si součástí slovesného lemmatu (tyto případy jsou popsány v odd. 2.4), kdy jde o tvarotvorný formant vytvářející reflexivní formu slovesa typickou pro deagentní diatezi (viz odd. 4.2) nebo kdy je užití reflexivního zájmena příznakem reciprocity (viz odd. 4.4).
- ^[13] Vzhledem k víceznačnosti klitik, která činí problémy jak (zejména nerodilým) mluvčím češtiny, tak při automatickém zpracování jazyka, dostala reflexivita vyjádřená klitiky v lexikografickém zpracování přednost.
- ^[14] V případě odvozených recipročních sloves (typ B) a jejich základových tranzitivních sloves (typ C) je ve VALLEXu uváděna reciprocita u obou typů.
- ^[15] Případy, kdy do vztahu reciprocity vstupují více než dva situační participanty, jsou řídké a pro češtinu zatím málo zkoumané; VALLEX popisuje pouze dvě lexikální jednotky s trojnou reciprocitou, a to lexikální jednotky sloves představovatimpf — představitpf a seznamovatimpf — seznámitpf.
- ^[16] Ve zpracování modálních sloves, která jsou na pomezí gramatiky a lexika, se VALLEX odchyluje od teorie FGP. Ve FGP jsou modální slovesa muset / musit, mít, chtít, hodlat, moci / moct, dát se, smět, dovést a umět zachycena pomocí gramatémů u významových sloves (nemají tedy valenční rámec). Naproti tomu ve VALLEXu jsou kvůli úplnosti a lexikální proměnlivosti pro modální význam těchto sloves vyčleněny lexikální jednotky, nejsou však zachyceny všechny jejich syntaktické zvláštnosti. Protože některá z těchto sloves jsou víceznačná (např. mít je modální v užití Jan má připravit večeři., ale plnovýznamové v užití Jan má spoustu peněz.), mohou být popsána v několika lexikálních jednotkách.

### Seznam literatury

- Havránek et al. (1964)
  Havránek, B. et al. (ed.) (1964): Slovník spisovného jazyka českého. Praha, Academia. (Co-editors: Bělič, J. – Helcl, M. – Jedlička, A. et al.)
- Isačenko (1960)
  Isačenko, A. V. (1960): Slovesný vid, slovesná akce a obecný charakter slovesného děje. Slovo a slovesnost. 21(1), s. 9–16.
- Karlík et al. (2002)
  Karlík, P. – Nekula, M. – Pleskalová, J. (ed.) (2002): Encyklopedický slovník češtiny. Praha, Nakladatelství Lidové noviny.
- Kettnerová – Lopatková (2014)
  Kettnerová, V. – Lopatková, M. (2014): Reflexive Verbs in a Valency Lexicon: The Case of Czech Reflexive Morphemes. In Abel, A. – Vettori, C. – Ralli, N. (ed.) Proceedings of the XVI EURALEX International Congress: The User in Focus, s. 1007–1023, Italy, Bolzano/Bozen, EURAC research.
- Panevová (1980)
  Panevová, J. (1980): Formy a funkce ve stavbě české věty. Praha, Academia.
- Panevová (1994)
  Panevová, J. (1994): Valency Frames and the Meaning of the Sentence. In Luelsdorff, P. A. (ed.) The Prague School of Structural and Functional Linguistics, s. 223–243. Amsterdam – Philadelphia, John Benjamins Publishing Company.
- Panevová (1996)
  Panevová, J. (1996): More Remarks on Control.: Prague Linguistic Circle Papers. 2, s. 101–120.
- Panevová (1999)
  Panevová, J. (1999): Česká reciproční zájmena a slovesná valence. Slovo a slovesnost. 60(4), s. 269–275.
- Panevová (2007)
  Panevová, J. (2007): Znovu o reciprocitě.: Slovo a slovesnost. 68(2), s. 91–100.
- Panevová et al. (2014)
  Panevová, J. et al. (2014): Mluvnice současné češtiny 2, Syntax na základě anotovaného korpusu. Praha, Karolinum. (Co-authors: Hajičová, E. – Kettnerová, V. – Lopatková, M. – Mikulová, M. – Ševčíková, M.)
- Panevová – Mikulová (2007)
  Panevová, J. – Mikulová, M. (2007): On Reciprocity. The Prague Bulletin of Mathematical Linguistics. 87, s. 27–40.
- Sgall et al. (1986a)
  Sgall, P. – Hajičová, E. – Panevová, J. (1986a): The Meaning of the Sentence in Its Semantic and Pragmatic Aspects. Dordrecht, Reidel.

## Obsah